Stan Math Library: stan/math/prim/scal/prob/double_exponential_rng.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
double_exponential_rng.hpp File Reference
`#include <boost/random/uniform_01.hpp>`
`#include <boost/random/variate_generator.hpp>`
`#include <stan/math/prim/scal/err/check_consistent_sizes.hpp>`
`#include <stan/math/prim/scal/err/check_finite.hpp>`
`#include <stan/math/prim/scal/err/check_not_nan.hpp>`
`#include <stan/math/prim/scal/err/check_positive_finite.hpp>`
`#include <stan/math/prim/scal/fun/value_of.hpp>`
`#include <stan/math/prim/scal/fun/log1m.hpp>`
`#include <stan/math/prim/scal/fun/constants.hpp>`
`#include <stan/math/prim/scal/meta/include_summand.hpp>`
`#include <stan/math/prim/scal/fun/sign.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<class RNG >
double | stan::math::double_exponential_rng (const double mu, const double sigma, RNG &rng)

[ Stan Home Page ] © 2011–2016, Stan Development Team.